#!/bin/bash
#
# NOTE: intentionally /bin/bash as otherwise "read -n ..." does not work on Linux
#
# NOTE: this script must be placed in the tmpStick "oorexx" directory
#       as the locaation is relevant for creating the batch/shell scripts
#
# /*----------------------------------------------------------------------------*/
# /*                                                                            */
# /* Copyright (c) 2020 Rexx Language Association. All rights reserved.         */
# /*                                                                            */
# /* This program and the accompanying materials are made available under       */
# /* the terms of the Common Public License v1.0 which accompanies this         */
# /* distribution. A copy is also available at the following address:           */
# /* http://www.oorexx.org/license.html                                         */
# /*                                                                            */
# /* Redistribution and use in source and binary forms, with or                 */
# /* without modification, are permitted provided that the following            */
# /* conditions are met:                                                        */
# /*                                                                            */
# /* Redistributions of source code must retain the above copyright             */
# /* notice, this list of conditions and the following disclaimer.              */
# /* Redistributions in binary form must reproduce the above copyright          */
# /* notice, this list of conditions and the following disclaimer in            */
# /* the documentation and/or other materials provided with the distribution.   */
# /*                                                                            */
# /* Neither the name of Rexx Language Association nor the names                */
# /* of its contributors may be used to endorse or promote products             */
# /* derived from this software without specific prior written permission.      */
# /*                                                                            */
# /* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        */
# /* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          */
# /* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS          */
# /* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
# /* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,      */
# /* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED   */
# /* TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,        */
# /* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY     */
# /* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING    */
# /* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         */
# /* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               */
# /*                                                                            */
# /*----------------------------------------------------------------------------*/

UNAME_SYSTEM=`(uname -s) 2>/dev/null`   || UNAME_SYSTEM=unknown
UNAME_MACHINE=`(uname -m) 2>/dev/null`  || UNAME_MACHINE=unknown

# "2020-09-29, rgf, cf. https://stackoverflow.com/questions/4774054/reliable-way-for-a-bash-script-to-get-the-full-path-to-itself"
SCRIPTPATH="$( cd "$(dirname "$0")" >/dev/null 2>&1 ; pwd -P )"

REXXPGM=do_the_work.rex

# debug
# echo system: ${UNAME_SYSTEM} machine: ${UNAME_MACHINE}
# echo SCRIPTPATH=$SCRIPTPATH

case "${UNAME_SYSTEM}" in

    CYGWIN_NT-10.0-WOW)
       echo "Setting for Windows (Cygwin, development environment)"

       if [ $UNAME_MACHINE = i686 ]
       then
          echo 32 bit machine
       else
          echo not a 32 bit machine
       fi

       REXX=${SCRIPTPATH}/${UNAME_SYSTEM}/x86_64/bin/rexx
       # exit
       ;;

    Darwin)
      echo "Setting for MacOS"
      REXX=${SCRIPTPATH}/${UNAME_SYSTEM}/x86_64/bin/rexx
      ;;

    Linux)
      echo "Setting for Linux"
      if [ $UNAME_MACHINE = x86_64 ]
      then
         echo 64 bit machine
         REXX=${SCRIPTPATH}/${UNAME_SYSTEM}/x86_64/bin/rexx
      else
         echo assuming 32 bit machine
         REXX=${SCRIPTPATH}/${UNAME_SYSTEM}/x86/bin/rexx
      fi
      ;;

    *)
    echo "Unsupported OS"
    break ;
    ;;

esac

echo $0: $REXX "$SCRIPTPATH/$REXXPGM"
$REXX "$SCRIPTPATH/$REXXPGM"

read -n1 -r -p "Press any key to continue ..." key
