#!/bin/sh
#
# /*----------------------------------------------------------------------------*/
# /*                                                                            */
# /* Copyright (c) 2020 Rexx Language Association. All rights reserved.         */
# /*                                                                            */
# /* This program and the accompanying materials are made available under       */
# /* the terms of the Common Public License v1.0 which accompanies this         */
# /* distribution. A copy is also available at the following address:           */
# /* http://www.oorexx.org/license.html                                         */
# /*                                                                            */
# /* Redistribution and use in source and binary forms, with or                 */
# /* without modification, are permitted provided that the following            */
# /* conditions are met:                                                        */
# /*                                                                            */
# /* Redistributions of source code must retain the above copyright             */
# /* notice, this list of conditions and the following disclaimer.              */
# /* Redistributions in binary form must reproduce the above copyright          */
# /* notice, this list of conditions and the following disclaimer in            */
# /* the documentation and/or other materials provided with the distribution.   */
# /*                                                                            */
# /* Neither the name of Rexx Language Association nor the names                */
# /* of its contributors may be used to endorse or promote products             */
# /* derived from this software without specific prior written permission.      */
# /*                                                                            */
# /* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        */
# /* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          */
# /* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS          */
# /* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
# /* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,      */
# /* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED   */
# /* TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,        */
# /* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY     */
# /* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING    */
# /* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         */
# /* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               */
# /*                                                                            */
# /*----------------------------------------------------------------------------*/
#
# 2020-09-28, rgf, Darwin and Linux: start script above "bin/" "lib/" directory:
#                  will create a subdir "stick", copy the dirs there and zip
#                  them up and copy the zip-archive to the script's location
#
#                  - unzip to the "oorexx" directory
#

UNAME_SYSTEM=`(uname -s)`
UNAME_MACHINE=`(uname -m)`

if [ $UNAME_MACHINE = x86_64 ]
then
 echo 64 bit machine
 RGF_MACHINE=x86_64
else
 echo assuming 32 bit machine
 RGF_MACHINE=x86
fi

# get this script's path
SCRIPTPATH="$( cd "$(dirname "$0")" >/dev/null 2>&1 ; pwd -P )"

echo $UNAME_SYSTEM - creating stick zipfile ...
rm -rf stick
mkdir stick
mkdir stick/${UNAME_SYSTEM}
mkdir stick/${UNAME_SYSTEM}/${RGF_MACHINE}

cp -pR bin stick/${UNAME_SYSTEM}/${RGF_MACHINE}/bin
# make sure executable bit is set
chmod 755  stick/${UNAME_SYSTEM}/${RGF_MACHINE}/bin/*

cp -pR lib stick/${UNAME_SYSTEM}/${RGF_MACHINE}/lib
# make sure executable bit is set
chmod 755  stick/${UNAME_SYSTEM}/${RGF_MACHINE}/lib/*

cp -pR share stick/${UNAME_SYSTEM}/${RGF_MACHINE}/share
cp -pR include stick/${UNAME_SYSTEM}/${RGF_MACHINE}/include

ZIP_NAME=stick${UNAME_SYSTEM}-${RGF_MACHINE}
cd stick
zip -9ry ${ZIP_NAME} *
zip -d ${ZIP_NAME} "*build-id*"
cp -p ${ZIP_NAME}.zip ${SCRIPTPATH}/${ZIP_NAME}.zip
cd ..

